@@ -3,7 +3,7 @@
 
 use 5.014;
 use warnings;
-use DateTime;
+use Time::Piece;
 
 use lib '../lib', 'lib';
 use Win32::Console::DotNet;
@@ -13,9 +13,9 @@ sub main {
   #
   Console->Clear();
 
-  my $dat = DateTime->now(time_zone => 'local');
+  my $dat = localtime;
 
-  Console->Write("\nToday is %s at %s.", $dat->dmy('/'), $dat->hms);
+  Console->Write("\nToday is %s at %s.", $dat->mdy, $dat->hms);
   Console->Write("\nPress Enter key to continue... ");
   Console->ReadLine();
   return 0;
@@ -27,11 +27,8 @@ __END__
 
 =pod
 
-=begin comment
-
 The example displays output like the following:
+
     Today is 10/26/2015 at 12:22:22 PM.
 
     Press Enter key to continue...
-
-=end comment
